pub fn measure_allocations(
allocator: Res<'_, AppReflectAllocator>,
diagnostics: Diagnostics<'_, '_>,
)Expand description
Measures the number of allocations in the allocator and other diagnostics when enabled
pub fn measure_allocations(
allocator: Res<'_, AppReflectAllocator>,
diagnostics: Diagnostics<'_, '_>,
)Measures the number of allocations in the allocator and other diagnostics when enabled