Module arg_meta

Module arg_meta 

Trait implementations to help with function dispatch.

Traits

ArgMeta
Describes an argument to a script function. Provides necessary information for the function to handle dispatch.
ScriptArgument
Marker trait for types that can be used as arguments to a script function.
ScriptReturn
Marker trait for types that can be used as return values from a script function.
TypedScriptArgument
Marker trait for types that can be used as arguments to a script function. And contain type information.
TypedScriptReturn
Marker trait for types that can be used as return values from a script function. And contain type information.