pub struct DummyScriptFunctionRegistry(pub ScriptFunctionRegistryArc);Expand description
Identical to the AppScriptFunctionRegistry, but the functions only exist for docs purposes, use if you provide functions at a lower level,
but still want to include the function in the docs
Tuple Fields
0: ScriptFunctionRegistryArcTrait Implementations
Sourceimpl Clone for DummyScriptFunctionRegistry
impl Clone for DummyScriptFunctionRegistry
Sourcefn clone(&self) -> DummyScriptFunctionRegistry
fn clone(&self) -> DummyScriptFunctionRegistry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DummyScriptFunctionRegistry
impl Debug for DummyScriptFunctionRegistry
Sourceimpl DebugWithTypeInfo for DummyScriptFunctionRegistry
impl DebugWithTypeInfo for DummyScriptFunctionRegistry
Sourcefn to_string_with_type_info(
&self,
f: &mut Formatter<'_>,
type_info_provider: Option<&dyn GetTypeInfo>,
) -> Result<(), Error>
fn to_string_with_type_info( &self, f: &mut Formatter<'_>, type_info_provider: Option<&dyn GetTypeInfo>, ) -> Result<(), Error>
Format the value using the provided type info provider if available
Sourceimpl Default for DummyScriptFunctionRegistry
impl Default for DummyScriptFunctionRegistry
Sourcefn default() -> DummyScriptFunctionRegistry
fn default() -> DummyScriptFunctionRegistry
Returns the “default value” for a type. Read more
impl Resource for DummyScriptFunctionRegistry