pub struct Ref<'w, T>(pub &'w T);Expand description
A wrapper around a reference to a value of type T.
This can be used to retrieve a reference out of a ScriptValue::Reference corresponding to the type T.
Before downcasting the reference, it will claim write access to the object to ensure that the reference is valid.
However, the access is NOT released when the Mut is dropped. This is not unsafe but can lead to deadlocks if not released later.
The script function calling mechanism will take care of releasing all accesses claimed during the function call.
Tuple Fields
0: &'w TTrait Implementations
Sourceimpl<T> ArgMeta for Ref<'_, T>
impl<T> ArgMeta for Ref<'_, T>
Sourcefn default_value() -> Option<ScriptValue>
fn default_value() -> Option<ScriptValue>
The default value for the argument. Used when the argument is not provided.
Sourceimpl<T> FromScript for Ref<'_, T>where
T: FromReflect,
impl<T> FromScript for Ref<'_, T>where
T: FromReflect,
Sourcefn from_script(
value: ScriptValue,
world: WorldAccessGuard<'_>,
) -> Result<<Ref<'_, T> as FromScript>::This<'_>, InteropError>
fn from_script( value: ScriptValue, world: WorldAccessGuard<'_>, ) -> Result<<Ref<'_, T> as FromScript>::This<'_>, InteropError>
Construct a value of type
T from a ScriptValue.Sourceimpl<'a, T> GetTypeDependencies for Ref<'a, T>where
T: GetTypeRegistration,
impl<'a, T> GetTypeDependencies for Ref<'a, T>where
T: GetTypeRegistration,
Sourcetype Underlying = T
type Underlying = T
In the majority of the implementations, this will be
Self
However some types might be facades for other types, in which case this will be the underlying typeSourcefn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Registers the type dependencies of the implementing type with the given
TypeRegistry.Sourceimpl<T> TypedThrough for Ref<'_, T>where
T: Typed,
impl<T> TypedThrough for Ref<'_, T>where
T: Typed,
Sourcefn through_type_info() -> ThroughTypeInfo
fn through_type_info() -> ThroughTypeInfo
Get the
ThroughTypeInfo for the type.Auto Trait Implementations
impl<'w, T> Freeze for Ref<'w, T>
impl<'w, T> RefUnwindSafe for Ref<'w, T>where
T: RefUnwindSafe,
impl<'w, T> Send for Ref<'w, T>where
T: Sync,
impl<'w, T> Sync for Ref<'w, T>where
T: Sync,
impl<'w, T> Unpin for Ref<'w, T>
impl<'w, T> UnwindSafe for Ref<'w, T>where
T: RefUnwindSafe,