pub struct ScriptingPluginConfiguration<P>where
P: IntoScriptPluginParams + ?Sized,{
pub pre_handling_callbacks: &'static [fn(&ScriptAttachment, &mut <P as IntoScriptPluginParams>::C) -> Result<(), InteropError>],
pub context_initialization_callbacks: &'static [fn(&ScriptAttachment, &mut <P as IntoScriptPluginParams>::C) -> Result<(), InteropError>],
pub emit_responses: bool,
pub runtime: &'static <P as IntoScriptPluginParams>::R,
pub language_extensions: &'static LanguageExtensions,
}Expand description
A set of global* configs keyed by the plugin params type.
Configuration is immutable after initialization.
Configs contained here should be
*global meaning stored in thread-locals, i.e. not annoyingly global, but pretty global.
Fields
pre_handling_callbacks: &'static [fn(&ScriptAttachment, &mut <P as IntoScriptPluginParams>::C) -> Result<(), InteropError>]callbacks executed before a handler callback is executed every time
context_initialization_callbacks: &'static [fn(&ScriptAttachment, &mut <P as IntoScriptPluginParams>::C) -> Result<(), InteropError>]callbacks executed once after creating a context but before executing it for the first time
emit_responses: boolWhether to emit responses from the core callbacks like on_script_loaded.
runtime: &'static <P as IntoScriptPluginParams>::RThe configured runtime for the plugin
language_extensions: &'static LanguageExtensionsThe language extensions this plugin supports