pub enum LuaMat2 {
    Owned(UnsafeCell<Mat2>, Arc<RwLock<RawRwLock, ()>>),
    Ref(ScriptRef),
}
A script wrapper for the type Mat2

Variants

Implementations

source

impl LuaMat2

source

pub fn script_ref(&self, world_ptr: WorldPointer) -> ScriptRef

Creates a script reference pointing to the wrapped value.

Depending on this value it may be a lua owned or reflect relative reference

source

pub fn new(b: Mat2) -> LuaMat2

source

pub fn new_ref(b: ScriptRef) -> LuaMat2

source

pub fn val<G, F>(&self, accessor: F) -> Result<G, ReflectionError>where F: FnOnce(&Mat2) -> G,

Perform an operation on the base type and optionally retrieve something by value may require a read lock on the world in case this is a reference

source

pub fn val_mut<G, F>(&mut self, accessor: F) -> Result<G, ReflectionError>where F: FnOnce(&mut Mat2) -> G,

source

pub fn apply_self_to_base( &self, other: &mut ScriptRef ) -> Result<(), ReflectionError>

Applies Self to another ScriptRef. may require a write lock on the world

source

pub fn inner(&self) -> Result<Mat2, ReflectionError>where Mat2: Clone,

retrieves the underlying value by cloning it