Trait implementations to help with function dispatch.
Traits
- ArgMeta
- Describes an argument to a script function. Provides necessary information for the function to handle dispatch.
- Script
Argument - Marker trait for types that can be used as arguments to a script function.
- Script
Return - Marker trait for types that can be used as return values from a script function.
- Typed
Script Argument - Marker trait for types that can be used as arguments to a script function. And contain type information.
- Typed
Script Return - Marker trait for types that can be used as return values from a script function. And contain type information.